@@ -882,7 +882,14 @@ class Game(object):
         if fps is None:
             fps = self.fps
 
-        return r.game_clock.tick(fps)
+        tp = r.game_clock.tick(fps)
+
+        r.cache.prune_time += tp
+        if r.cache.prune_time >= r.CACHE_PRUNE_TIME:
+            r.cache.prune_time = 0
+            r.cache.prune()
+
+        return tp
 
     def refresh(self):
         """
@@ -1357,7 +1364,7 @@ class Game(object):
         """
         pass
 
-    def event_mouse_collision(self, other):
+    def event_mouse_collision(self, other, xdirection, ydirection):
         """
         Proxy for :meth:`sge.game.mouse.event_collision`.  See the
         documentation for :meth:`sge.Object.event_collision` for more
@@ -1365,38 +1372,6 @@ class Game(object):
         """
         pass
 
-    def event_mouse_collision_left(self, other):
-        """
-        Proxy for :meth:`sge.game.mouse.event_collision_left`.  See the
-        documentation for :meth:`sge.Object.event_collision_left` for
-        more information.
-        """
-        self.event_mouse_collision(other)
-
-    def event_mouse_collision_right(self, other):
-        """
-        Proxy for :meth:`sge.game.mouse.event_collision_right`.  See the
-        documentation for :meth:`sge.Object.event_collision_right` for
-        more information.
-        """
-        self.event_mouse_collision(other)
-
-    def event_mouse_collision_top(self, other):
-        """
-        Proxy for :meth:`sge.game.mouse.event_collision_top`.  See the
-        documentation for :meth:`sge.Object.event_collision_top` for
-        more information.
-        """
-        self.event_mouse_collision(other)
-
-    def event_mouse_collision_bottom(self, other):
-        """
-        Proxy for :meth:`sge.game.mouse.event_collision_bottom`.  See
-        the documentation for :meth:`sge.Object.event_collision_bottom`
-        for more information.
-        """
-        self.event_mouse_collision(other)
-
     def event_paused_step(self, time_passed, delta_mult):
         """
         See the documentation for :meth:`sge.Game.event_step` for more
