@@ -24,6 +24,7 @@ import os
 import sys
 import traceback
 import math
+import warnings
 
 import pygame
 import six
@@ -852,8 +853,9 @@ class Object(object):
                 if area is None:
                     area = (None, None)
                 i, j = area
-                if (i in room.rd["collision_areas"] and
-                        j in room.rd["collision_areas"][i]):
+                if (i is not None and j is not None and
+                        i < len(room.rd["collision_areas"]) and
+                        j < len(room.rd["collision_areas"][i])):
                     room_area = room.rd["collision_areas"][i][j]
                 else:
                     room_area = room.rd["collision_area_void"]
@@ -861,10 +863,11 @@ class Object(object):
                     if i is not None or j is not None:
                         e = "A collision area existed in a {} object, but not in the room!".format(
                             self.__class__.__name__)
+                        e += "\nAttempted area: ({}, {})".format(i, j)
+                        x = len(room.rd["collision_areas"])
+                        y = len(room.rd["collision_areas"][0]) if x else 0
+                        e += "\nAvailable collision areas: {}x{}".format(x, y)
                         warnings.warn(e)
-                        print("Attempted area: ({}, {})".format(i, j))
-                        print("Available collision areas:")
-                        print(room.rd["collision_areas"])
 
                 for obj in room_area:
                     if obj is not self and obj.tangible and obj not in others:
