@@ -171,11 +171,11 @@ class Room(object):
 
             if self is sge.game.current_room and self.rd["started"]:
                 obj.event_create()
+                obj.rd["collision_areas"] = []
+                o_update_collision_lists(obj)
             else:
                 self.__new_objects.append(obj)
 
-            o_update_collision_lists(obj)
-
     def remove(self, obj):
         """
         Remove an object from the room.
@@ -259,18 +259,19 @@ class Room(object):
             obj.rd["collision_areas"] = []
             o_update_collision_lists(obj)
 
+        # This is stored in a variable to prevent problems with
+        # rd["started"] being False during the start/create events.
         started = self.rd["started"]
         self.rd["started"] = True
         if not started:
             self.event_room_start()
-            for obj in self.objects:
-                obj.event_create()
         else:
-            while self.__new_objects:
-                self.__new_objects[0].event_create()
-                del self.__new_objects[0]
             self.event_room_resume()
 
+        while self.__new_objects:
+            self.__new_objects[0].event_create()
+            del self.__new_objects[0]
+
     def project_dot(self, x, y, z, color):
         """
         Project a single-pixel dot onto the room.
