@@ -243,8 +243,7 @@ class Sprite(object):
         self.name = name
         self.__transparent = None
         self.rd["baseimages"] = []
-        self.rd["images"] = []
-        self.rd["masks"] = {}
+        self.rd["drawcycle"] = 0
 
         fname_single = []
         fname_frames = []
@@ -914,8 +913,6 @@ class Sprite(object):
           is the first frame; set to :const:`None` to draw on all
           frames.
         """
-        if not isinstance(font, sge.Font):
-            font = sge.game.fonts[font]
         if not isinstance(color, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(color))
             raise TypeError(e)
@@ -1176,21 +1173,20 @@ class Sprite(object):
 
         The sprite's origin is set based on ``halign`` and ``valign``.
         """
-        i = (cls, tuple(font.name), font.size, font.underline, font.bold,
-             font.italic, text, width, height, str(color), halign, valign,
-             anti_alias)
-        if i in r.cache.text_sprite:
-            s = r.cache.text_sprite[i]
-        else:
+        i = ("text_sprite", cls, tuple(font.name), font.size, font.underline,
+             font.bold, font.italic, text, width, height, str(color), halign,
+             valign, anti_alias)
+        s = r.cache.get(i)
+        if s is None:
             w = font.get_width(text, width, height)
             h = font.get_height(text, width, height)
             x = {"left": 0, "right": w, "center": w / 2}.get(halign.lower(), 0)
             y = {"top": 0, "bottom": h, "middle": h / 2}.get(valign.lower(), 0)
             s = cls(width=w, height=h, origin_x=x, origin_y=y)
             s.draw_text(font, text, x, y, width, height, color, halign, valign)
-            r.cache.text_sprite[i] = s
 
-        return s
+        r.cache.add(i, s)
+        return s.copy()
 
     @classmethod
     def from_tileset(cls, fname, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
