@@ -554,8 +554,9 @@ def o_update_collision_lists(self):
                 if area is None:
                     area = (None, None)
                 i, j = area
-                if (i in room.rd["collision_areas"] and
-                        j in room.rd["collision_areas"][i]):
+                if (i is not None and j is not None and
+                        i < len(room.rd["collision_areas"]) and
+                        j < len(room.rd["collision_areas"][i])):
                     ca = room.rd["collision_areas"][i][j][:]
                     while self in ca:
                         ca.remove(self)
@@ -564,10 +565,11 @@ def o_update_collision_lists(self):
                     if i is not None or j is not None:
                         e = "A collision area existed in a {} object, but not in the room!".format(
                             self.__class__.__name__)
+                        e += "\nAttempted area: ({}, {})".format(i, j)
+                        x = len(room.rd["collision_areas"])
+                        y = len(room.rd["collision_areas"][0]) if x else 0
+                        e += "\nAvailable collision areas: {}x{}".format(x, y)
                         warnings.warn(e)
-                        print("Attempted area: ({}, {})".format(i, j))
-                        print("Available collision areas:")
-                        print(room.rd["collision_areas"])
 
                     ca = room.rd["collision_area_void"][:]
                     while self in ca:
@@ -579,8 +581,9 @@ def o_update_collision_lists(self):
                 if area is None:
                     area = (None, None)
                 i, j = area
-                if (i in room.rd["collision_areas"] and
-                        j in room.rd["collision_areas"][i]):
+                if (i is not None and j is not None and
+                        i < len(room.rd["collision_areas"]) and
+                        j < len(room.rd["collision_areas"][i])):
                     ca = room.rd["collision_areas"][i][j][:]
                     ca.append(self)
                     room.rd["collision_areas"][i][j] = ca
@@ -588,10 +591,11 @@ def o_update_collision_lists(self):
                     if i is not None or j is not None:
                         e = "A collision area existed in a {} object, but not in the room!".format(
                             self.__class__.__name__)
+                        e += "\nAttempted area: ({}, {})".format(i, j)
+                        x = len(room.rd["collision_areas"])
+                        y = len(room.rd["collision_areas"][0]) if x else 0
+                        e += "\nAvailable collision areas: {}x{}".format(x, y)
                         warnings.warn(e)
-                        print("Attempted area: ({}, {})".format(i, j))
-                        print("Available collision areas:")
-                        print(room.rd["collision_areas"])
 
                     ca = room.rd["collision_area_void"][:]
                     ca.append(self)
